==> cdk-cx-api-0.26.0-sources.jar: software/amazon/awscdk/cxapi/BuildManifest.java <==
package software.amazon.awscdk.cxapi;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:52:17.978Z")
public interface BuildManifest extends software.amazon.jsii.JsiiSerializable {
    java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> getSteps();
    void setSteps(final java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> value);

    /**
     * @return a {@link Builder} of {@link BuildManifest}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link BuildManifest}
     */
    final class Builder {
        private java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> _steps;

        /**
         * Sets the value of Steps
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withSteps(final java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> value) {
            this._steps = java.util.Objects.requireNonNull(value, "steps is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BuildManifest}
         * @throws NullPointerException if any required attribute was not provided
         */
        public BuildManifest build() {
            return new BuildManifest() {
                private java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> $steps = java.util.Objects.requireNonNull(_steps, "steps is required");

                @Override
                public java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> getSteps() {
                    return this.$steps;
                }

                @Override
                public void setSteps(final java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> value) {
                    this.$steps = java.util.Objects.requireNonNull(value, "steps is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.cxapi.BuildManifest {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        @Override
        public java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> getSteps() {
            return this.jsiiGet("steps", java.util.Map.class);
        }

        @Override
        public void setSteps(final java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> value) {
            this.jsiiSet("steps", java.util.Objects.requireNonNull(value, "steps is required"));
        }
    }
}

==> cdk-cx-api-0.27.0-sources.jar: software/amazon/awscdk/cxapi/BuildManifest.java <==
package software.amazon.awscdk.cxapi;

@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:30:07.022Z")
public interface BuildManifest extends software.amazon.jsii.JsiiSerializable {
    java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> getSteps();

    /**
     * @return a {@link Builder} of {@link BuildManifest}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link BuildManifest}
     */
    final class Builder {
        private java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> _steps;

        /**
         * Sets the value of Steps
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withSteps(final java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> value) {
            this._steps = java.util.Objects.requireNonNull(value, "steps is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BuildManifest}
         * @throws NullPointerException if any required attribute was not provided
         */
        public BuildManifest build() {
            return new BuildManifest() {
                private final java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> $steps = java.util.Objects.requireNonNull(_steps, "steps is required");

                @Override
                public java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> getSteps() {
                    return this.$steps;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("steps", om.valueToTree(this.getSteps()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.cxapi.BuildManifest {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        @Override
        public java.util.Map<java.lang.String, software.amazon.awscdk.cxapi.BuildStep> getSteps() {
            return this.jsiiGet("steps", java.util.Map.class);
        }
    }
}
